@@ -26,6 +26,7 @@ from .common import terminal_width
 from .metadata import find_enclosing_workspace
 from .resultspace import get_resultspace_environment
 from .terminal_color import ColorMapper
+from .utils import entry_points
 
 color_mapper = ColorMapper()
 clr = color_mapper.clr
@@ -120,9 +121,7 @@ class Context(object):
         if cls.KEYS:
             return
 
-        from pkg_resources import iter_entry_points
-
-        for entry_point in iter_entry_points(group=cls.CATKIN_SPACES_GROUP):
+        for entry_point in entry_points(group=cls.CATKIN_SPACES_GROUP):
             ep_dict = entry_point.load()
             cls.STORED_KEYS.append(entry_point.name + '_space')
             cls.SPACES[entry_point.name] = ep_dict
@@ -503,9 +502,9 @@ class Context(object):
                     "should call @{yf}`catkin clean`@| to remove all "
                     "references to the previous CMAKE_PREFIX_PATH.\\n\\n"
                     "@{cf}Cached CMAKE_PREFIX_PATH:@|\\n\\t@{yf}{}@|\\n"
-                    "@{cf}Other workspace to extend:@|\\n\\t@{yf}{_Context__extend_path}@|\\n"
+                    "@{cf}Other workspace to extend:@|\\n\\t@{yf}{}@|\\n"
                     "@{cf}Other workspace's CMAKE_PREFIX_PATH:@|\\n\\t@{yf}{}@|").format(
-                    self.cached_cmake_prefix_path, self.env_cmake_prefix_path)]
+                        self.cached_cmake_prefix_path, self.extend_path, self.env_cmake_prefix_path)]
 
         elif self.env_cmake_prefix_path and\
                 self.cached_cmake_prefix_path and\
