@@ -21,13 +21,11 @@ import time
 import traceback
 from queue import Queue
 
-import pkg_resources
 import yaml
 
 try:
     from catkin_pkg.package import InvalidPackage
     from catkin_pkg.package import parse_package
-    from catkin_pkg.packages import find_packages
     from catkin_pkg.topological_order import topological_order_packages
 except ImportError as e:
     sys.exit(
@@ -37,6 +35,7 @@ except ImportError as e:
 
 from catkin_tools.common import FakeLock
 from catkin_tools.common import expand_glob_package
+from catkin_tools.common import find_packages
 from catkin_tools.common import format_time_delta
 from catkin_tools.common import get_cached_recursive_build_depends_in_workspace
 from catkin_tools.common import get_recursive_run_depends_in_workspace
@@ -48,6 +47,7 @@ from catkin_tools.execution.executor import run_until_complete
 from catkin_tools.jobs.catkin import create_catkin_build_job
 from catkin_tools.jobs.catkin import create_catkin_clean_job
 from catkin_tools.jobs.catkin import get_prebuild_package
+from catkin_tools.utils import entry_points
 
 from .color import clr
 
@@ -480,7 +480,7 @@ def build_isolated_workspace(
     # Get all build type plugins
     build_job_creators = {
         ep.name: ep.load()['create_build_job']
-        for ep in pkg_resources.iter_entry_points(group='catkin_tools.jobs')
+        for ep in entry_points(group='catkin_tools.jobs')
     }
 
     # It's a problem if there aren't any build types available
