@@ -1,7 +1,7 @@
 import os
 import shutil
+from unittest import mock
 
-import mock
 import pytest
 
 from catkin_tools import config
